@@ -145,13 +145,13 @@ class Account(ABC):
 
         return transfer
 
-    def intra_account_transfer(self, api_key: str, to_account: Union[CashAccount | ReserveAccount], receiving_amount: Decimal) -> IntraAccountTransfer:
+    def intra_account_transfer(self, to_account: Union[CashAccount | ReserveAccount], receiving_amount: Decimal) -> IntraAccountTransfer:
         intra_account_transfer: IntraAccountTransfer = IntraAccountTransfer.execute(api_key, receiving_amount, self, to_account, self.user_profile.type)    # type: ignore[arg-type]
         if intra_account_transfer.is_successful:
             if isinstance(self, CashAccount):
-                self.balance = Account.get_by_profile_type_and_currency(api_key, self.user_profile.type, self.currency).balance
+                self.balance = Account.get_by_profile_type_and_currency(self.api_key, self.user_profile.type, self.currency).balance
             else:
-                self.balance = ReserveAccount.get_reserve_account_by_profile_type_currency_and_name(api_key, self.user_profile.type, self.currency, self.name, False).balance
+                self.balance = ReserveAccount.get_reserve_account_by_profile_type_currency_and_name(self.api_key, self.user_profile.type, self.currency, self.name, False).balance
 
         return intra_account_transfer
 
